@@ -18,18 +18,22 @@
 
 import copy
 import logging
+from urllib import parse
 
 from oslo_serialization import jsonutils
+from oslo_utils import importutils
 from oslo_utils import strutils
+import re
 import requests
-import six
 
 from manilaclient import exceptions
 
+from time import sleep  # noqa
+
 try:
-    from eventlet import sleep
-except ImportError:
-    from time import sleep  # noqa
+    osprofiler_web = importutils.try_import("osprofiler.web")
+except Exception:
+    pass
 
 
 class HTTPClient(object):
@@ -45,14 +49,14 @@ class HTTPClient(object):
 
     def __init__(self, endpoint_url, token, user_agent, api_version,
                  insecure=False, cacert=None, timeout=None, retries=None,
-                 http_log_debug=False):
+                 http_log_debug=False, cert=None):
         self.endpoint_url = endpoint_url
         self.base_url = self._get_base_url(self.endpoint_url)
-        self.retries = retries
+        self.retries = int(retries or 0)
         self.http_log_debug = http_log_debug
 
         self.request_options = self._set_request_options(
-            insecure, cacert, timeout)
+            insecure, cacert, timeout, cert)
 
         self.default_headers = {
             'X-Auth-Token': token,
@@ -78,17 +82,24 @@ class HTTPClient(object):
                 rql.addHandler(ch)
 
     def _get_base_url(self, url):
-        """Truncates url and returns transport, address, and port number."""
-        base_url = '/'.join(url.split('/')[:3]) + '/'
-        return base_url
+        """Truncates url and returns base endpoint"""
+        service_endpoint = parse.urlparse(url)
+        service_endpoint_base_path = re.search(
+            r'(.+?)/v([0-9]+|[0-9]+\.[0-9]+)(/.*|$)', service_endpoint.path)
+        base_path = (service_endpoint_base_path.group(1)
+                     if service_endpoint_base_path else '')
+        base_url = service_endpoint._replace(path=base_path)
+        return parse.urlunparse(base_url) + '/'
 
-    def _set_request_options(self, insecure, cacert, timeout=None):
+    def _set_request_options(self, insecure, cacert, timeout=None, cert=None):
         options = {'verify': True}
 
         if insecure:
             options['verify'] = False
         elif cacert:
             options['verify'] = cacert
+        if cert:
+            options['cert'] = cert
 
         if timeout:
             options['timeout'] = timeout
@@ -101,6 +112,9 @@ class HTTPClient(object):
 
         options = copy.deepcopy(self.request_options)
 
+        if osprofiler_web:
+            headers.update(osprofiler_web.get_trace_id_headers())
+
         if 'body' in kwargs:
             headers['Content-Type'] = 'application/json'
             options['data'] = jsonutils.dumps(kwargs['body'])
@@ -148,11 +162,11 @@ class HTTPClient(object):
                 if attempts > self.retries:
                     raise
 
-                self._logger.debug("Request error: %s" % six.text_type(e))
+                self._logger.debug("Request error: %s", str(e))
 
             self._logger.debug(
                 "Failed attempt(%(current)s of %(total)s), "
-                " retrying in %(sec)s seconds" % {
+                " retrying in %(sec)s seconds", {
                     'current': attempts,
                     'total': self.retries,
                     'sec': timeout
@@ -189,13 +203,13 @@ class HTTPClient(object):
             if "password" in data:
                 data = strutils.mask_password(data)
             string_parts.append(" -d '%s'" % data)
-        self._logger.debug("\nREQ: %s\n" % "".join(string_parts))
+        self._logger.debug("\nREQ: %s\n", "".join(string_parts))
 
     def log_response(self, resp):
         if not self.http_log_debug:
             return
         self._logger.debug(
-            "RESP: [%(code)s] %(headers)s\nRESP BODY: %(body)s\n" % {
+            "RESP: [%(code)s] %(headers)s\nRESP BODY: %(body)s\n", {
                 'code': resp.status_code,
                 'headers': resp.headers,
                 'body': resp.text
