@@ -19,16 +19,16 @@ Command-line interface to the OpenStack Manila API.
 """
 
 import argparse
+import csv
 import glob
-import imp
+from importlib import util as importlib_util
 import itertools
 import logging
 import os
 import pkgutil
 import sys
 
-from oslo_utils import encodeutils
-import six
+from oslo_utils import importutils
 
 from manilaclient import api_versions
 from manilaclient import client
@@ -44,6 +44,11 @@ DEFAULT_MAJOR_OS_SHARE_API_VERSION = "2"
 V1_MAJOR_VERSION = '1'
 V2_MAJOR_VERSION = '2'
 
+try:
+    osprofiler_profiler = importutils.try_import("osprofiler.profiler")
+except Exception:
+    pass
+
 
 logger = logging.getLogger(__name__)
 
@@ -62,7 +67,7 @@ class AllowOnlyOneAliasAtATimeAction(argparse.Action):
             self.calls[self.dest] = set()
 
         local_values = sorted(values) if isinstance(values, list) else values
-        self.calls[self.dest].add(six.text_type(local_values))
+        self.calls[self.dest].add(str(local_values))
 
         if len(self.calls[self.dest]) == 1:
             setattr(namespace, self.dest, local_values)
@@ -347,6 +352,29 @@ class OpenStackManilaShell(object):
         parser.add_argument('--os_cert',
                             help=argparse.SUPPRESS)
 
+        parser.add_argument('--os-key',
+                            metavar='<key>',
+                            default=cliutils.env('OS_KEY'),
+                            help='Defaults to env[OS_KEY].')
+        parser.add_argument('--os_key',
+                            help=argparse.SUPPRESS)
+
+        if osprofiler_profiler:
+            parser.add_argument('--profile',
+                                metavar='HMAC_KEY',
+                                default=cliutils.env('OS_PROFILE'),
+                                help='HMAC key to use for encrypting '
+                                'context data for performance profiling '
+                                'of operation. This key needs to match the '
+                                'one configured on the manila api server. '
+                                'Without key the profiling will not be '
+                                'triggered even if osprofiler is enabled '
+                                'on server side. Defaults to '
+                                'env[OS_PROFILE].')
+
+        parser.set_defaults(func=self.do_help)
+        parser.set_defaults(command='')
+
         return parser
 
     def get_subcommand_parser(self, version):
@@ -393,6 +421,14 @@ class OpenStackManilaShell(object):
                 module = module_loader.load_module(name)
                 yield name, module
 
+    def _load_module(self, name, path):
+        module_spec = importlib_util.spec_from_file_location(
+            name, path
+        )
+        module = importlib_util.module_from_spec(module_spec)
+        module_spec.loader.exec_module(module)
+        return module
+
     def _discover_via_contrib_path(self, api_version):
         module_path = os.path.dirname(os.path.abspath(__file__))
         version_str = 'v' + api_version.get_major_version()
@@ -405,7 +441,7 @@ class OpenStackManilaShell(object):
             if name == "__init__":
                 continue
 
-            module = imp.load_source(name, ext_path)
+            module = self._load_module(name, ext_path)
             yield name, module
 
     def _add_bash_completion_subparser(self, subparsers):
@@ -508,12 +544,15 @@ class OpenStackManilaShell(object):
             api_version = api_versions.get_api_version(
                 options.os_share_api_version)
 
-        major_version_string = six.text_type(api_version.ver_major)
+        major_version_string = str(api_version.ver_major)
         os_service_type = args.service_type
         if not os_service_type:
             os_service_type = constants.SERVICE_TYPES[major_version_string]
 
         os_endpoint_type = args.endpoint_type or DEFAULT_MANILA_ENDPOINT_TYPE
+        cert = args.os_cert or None
+        if cert and args.os_key:
+            cert = cert, args.os_key
 
         client_args = dict(
             username=args.os_username,
@@ -537,7 +576,7 @@ class OpenStackManilaShell(object):
             user_domain_name=args.os_user_domain_name,
             project_domain_id=args.os_project_domain_id,
             project_domain_name=args.os_project_domain_name,
-            cert=args.os_cert,
+            cert=cert,
             input_auth_token=args.os_token,
             service_catalog_url=args.bypass_url,
         )
@@ -566,8 +605,45 @@ class OpenStackManilaShell(object):
                                                       argv,
                                                       options)
 
+        profile = osprofiler_profiler and options.profile
+        if profile:
+            osprofiler_profiler.init(options.profile)
+
+        try:
+            decoder_path = (
+                '%s/%s' % (os.path.dirname(os.path.abspath(__file__)),
+                           'osc/v2/data/manila.csv')
+            )
+            with open(decoder_path) as f:
+                decoder_data = {
+                    r['manila command']: r['openstack command']
+                    for r in csv.DictReader(f, skipinitialspace=True)
+                }
+        except Exception:
+            # this is fine
+            decoder_data = {}
+
+        deprecation_message = ("manila CLI is deprecated and will be removed "
+                               "in the future. Use openstack CLI instead.")
+        cmd = args.func.__name__.lstrip('do_').replace("_", "-")
+        if decoder_data and cmd in decoder_data:
+            deprecation_message = " ".join([
+                deprecation_message,
+                "The equivalent command is \" openstack",
+                f"{decoder_data[cmd]}",
+                "\""
+            ])
+
+        print(deprecation_message, file=sys.stderr)
+
         args.func(self.cs, args)
 
+        if profile:
+            trace_id = osprofiler_profiler.get().get_base_id()
+            print("Profiling trace ID: %s" % trace_id)
+            print("To display trace use next command:\n"
+                  "osprofiler trace show --html %s " % trace_id)
+
     def _discover_client(self,
                          current_client,
                          os_api_version,
@@ -693,17 +769,13 @@ class OpenStackHelpFormatter(argparse.HelpFormatter):
 
 def main():
     try:
-        if sys.version_info >= (3, 0):
-            OpenStackManilaShell().main(sys.argv[1:])
-        else:
-            OpenStackManilaShell().main(
-                map(encodeutils.safe_decode, sys.argv[1:]))
+        OpenStackManilaShell().main(sys.argv[1:])
     except KeyboardInterrupt:
         print("... terminating manila client", file=sys.stderr)
         sys.exit(130)
     except Exception as e:
         logger.debug(e, exc_info=1)
-        print("ERROR: %s" % six.text_type(e), file=sys.stderr)
+        print("ERROR: %s" % str(e), file=sys.stderr)
         sys.exit(1)
 
 
