@@ -98,7 +98,7 @@ class BaseTestCase(base.ClientTestBase):
                 res["deleted"] = False
             if "client" not in res:
                 res["client"] = cls.get_cleanup_client()
-            if not(res["deleted"]):
+            if not res["deleted"]:
                 res_id = res["id"]
                 client = res["client"]
                 deletion_params = res.get("deletion_params")
@@ -320,7 +320,7 @@ class BaseTestCase(base.ClientTestBase):
             'description': description,
             'public': public,
             'snapshot': snapshot,
-            'metadata': metadata,
+            'metadata': metadata or {},
             'microversion': microversion,
             'wait': use_wait_option,
         }
@@ -368,6 +368,36 @@ class BaseTestCase(base.ClientTestBase):
         client.restore_share(shares_to_restore,
                              microversion=microversion)
 
+    @classmethod
+    def create_share_transfer(cls, share_id, name=None,
+                              client=None, microversion=None):
+        client = client or cls.get_admin_client()
+        return client.create_share_transfer(share_id, name=name,
+                                            microversion=microversion)
+
+    @classmethod
+    def delete_share_transfer(cls, transfer, client=None,
+                              microversion=None):
+        client = client or cls.get_admin_client()
+        client.delete_share_transfer(transfer, microversion=microversion)
+
+    @classmethod
+    def get_share_transfer(cls, transfer, client=None, microversion=None):
+        client = client or cls.get_admin_client()
+        return client.get_share_transfer(transfer, microversion=microversion)
+
+    @classmethod
+    def list_share_transfer(cls, client=None, microversion=None):
+        client = client or cls.get_admin_client()
+        return client.list_share_transfer(microversion=microversion)
+
+    @classmethod
+    def accept_share_transfer(cls, transfer, auth_key,
+                              client=None, microversion=None):
+        client = client or cls.get_admin_client()
+        client.accept_share_transfer(transfer, auth_key,
+                                     microversion=microversion)
+
     @classmethod
     def _determine_share_network_to_use(cls, client, share_type,
                                         microversion=None):
@@ -383,8 +413,9 @@ class BaseTestCase(base.ClientTestBase):
     @classmethod
     def create_security_service(cls, type='ldap', name=None, description=None,
                                 dns_ip=None, ou=None, server=None, domain=None,
-                                user=None, password=None, client=None,
-                                cleanup_in_class=False, microversion=None):
+                                user=None, password=None, default_ad_site=None,
+                                client=None, cleanup_in_class=False,
+                                microversion=None):
         if client is None:
             client = cls.get_admin_client()
         data = {
@@ -398,6 +429,7 @@ class BaseTestCase(base.ClientTestBase):
             'dns_ip': dns_ip,
             'ou': ou,
             'microversion': microversion,
+            'default_ad_site': default_ad_site,
         }
         ss = client.create_security_service(**data)
         resource = {
