@@ -122,6 +122,108 @@ class ShareTypesReadWriteTest(base.BaseTestCase):
             '2.41', True, False, None, None, None, None, None,
             description=data_utils.rand_name('test_share_type_description'))
 
+    @ddt.data(
+        ('name_updated_1', 'description_updated', True),
+        ('name_updated_2', 'description_updated', False),
+        ('name_updated_3', None, None),
+        (None, 'description_updated', None),
+        (None, None, True),
+        (None, None, False),
+    )
+    @ddt.unpack
+    def test_create_update_delete_share_type_2_50(self, new_name,
+                                                  new_description,
+                                                  new_is_public):
+        self.skip_if_microversion_not_supported('2.50')
+        microversion = '2.50'
+        share_type_name = data_utils.rand_name('share_type_update_test')
+
+        # Create share type
+        share_type = self.create_share_type(
+            name=share_type_name,
+            driver_handles_share_servers=False,
+            snapshot_support=None,
+            create_share_from_snapshot=None,
+            revert_to_snapshot=None,
+            mount_snapshot=None,
+            is_public=True,
+            microversion=microversion,
+            extra_specs={},
+            description="share_type_description")
+
+        st_id = share_type['ID']
+
+        # Update share type
+        st_updated = self.update_share_type(st_id, name=new_name,
+                                            description=new_description,
+                                            is_public=new_is_public,
+                                            microversion=microversion)
+        # Verify type name
+        if new_name:
+            self.assertEqual(new_name, st_updated['Name'])
+
+        # Verify type description
+        if new_description:
+            self.assertEqual(new_description, st_updated['Description'])
+
+        # Verify public
+        if new_is_public is not None:
+            self.assertEqual('public' if new_is_public else 'private',
+                             st_updated['Visibility'].lower())
+
+        # Delete share type
+        self.admin_client.delete_share_type(st_id, microversion=microversion)
+
+        # Wait for share type deletion
+        self.admin_client.wait_for_share_type_deletion(
+            st_id, microversion=microversion)
+
+        # Verify that it is not listed with common 'type-list' operation.
+        share_types = self.admin_client.list_share_types(
+            list_all=False, microversion=microversion)
+        self.assertFalse(any(st_id == st['ID'] for st in share_types))
+
+    def test_unset_share_type_description_2_50(self):
+        self.skip_if_microversion_not_supported('2.50')
+        microversion = '2.50'
+        share_type_name = data_utils.rand_name('share_type_update_test')
+
+        # Create share type
+        share_type = self.create_share_type(
+            name=share_type_name,
+            driver_handles_share_servers=False,
+            snapshot_support=None,
+            create_share_from_snapshot=None,
+            revert_to_snapshot=None,
+            mount_snapshot=None,
+            is_public=True,
+            microversion=microversion,
+            extra_specs={},
+            description="share_type_description")
+
+        st_id = share_type['ID']
+
+        # Update share type
+        new_description = ""
+        st_updated = self.update_share_type(st_id,
+                                            description=new_description,
+                                            microversion=microversion)
+
+        # Verify type description
+        self.assertEqual('None', st_updated['Description'])
+
+        # Delete share type
+        self.admin_client.delete_share_type(st_id, microversion=microversion)
+
+        # Wait for share type deletion
+        self.admin_client.wait_for_share_type_deletion(
+            st_id, microversion=microversion)
+
+        # Verify that it is not listed with common 'type-list' operation.
+        share_types = self.admin_client.list_share_types(
+            list_all=False, microversion=microversion)
+        self.assertFalse(any(st_id == st['ID'] for st in share_types))
+
     def _test_create_delete_share_type(self, microversion, is_public, dhss,
                                        spec_snapshot_support,
                                        spec_create_share_from_snapshot,
