@@ -15,14 +15,13 @@
 
 from manilaclient import api_versions
 from manilaclient import base
-from manilaclient.common.apiclient import base as common_base
 
 RESOURCE_PATH_LEGACY = '/os-quota-sets'
 RESOURCE_PATH = '/quota-sets'
 REPLICA_QUOTAS_MICROVERSION = "2.53"
 
 
-class QuotaSet(common_base.Resource):
+class QuotaSet(base.Resource):
 
     @property
     def id(self):
@@ -95,6 +94,7 @@ class QuotaSetManager(base.ManagerWithFind):
                    force=None, user_id=None, share_type=None,
                    share_groups=None, share_group_snapshots=None,
                    share_replicas=None, replica_gigabytes=None,
+                   per_share_gigabytes=None, encryption_keys=None,
                    resource_path=RESOURCE_PATH):
         self._check_user_id_and_share_type_args(user_id, share_type)
         body = {
@@ -110,6 +110,8 @@ class QuotaSetManager(base.ManagerWithFind):
                 'force': force,
                 'share_replicas': share_replicas,
                 'replica_gigabytes': replica_gigabytes,
+                'per_share_gigabytes': per_share_gigabytes,
+                'encryption_keys': encryption_keys,
             },
         }
 
@@ -183,7 +185,7 @@ class QuotaSetManager(base.ManagerWithFind):
             resource_path=RESOURCE_PATH,
         )
 
-    @api_versions.wraps(REPLICA_QUOTAS_MICROVERSION)  # noqa
+    @api_versions.wraps(REPLICA_QUOTAS_MICROVERSION, "2.61")  # noqa
     def update(self, tenant_id, user_id=None, share_type=None,  # noqa
                shares=None, snapshots=None, gigabytes=None,
                snapshot_gigabytes=None, share_networks=None,
@@ -201,6 +203,47 @@ class QuotaSetManager(base.ManagerWithFind):
             resource_path=RESOURCE_PATH
         )
 
+    @api_versions.wraps("2.62", "2.89")  # noqa
+    def update(self, tenant_id, user_id=None, share_type=None,  # noqa
+               shares=None, snapshots=None, gigabytes=None,
+               snapshot_gigabytes=None, share_networks=None,
+               share_groups=None, share_group_snapshots=None,
+               share_replicas=None, replica_gigabytes=None, force=None,
+               per_share_gigabytes=None):
+        self._validate_st_and_sn_in_same_request(share_type, share_networks)
+        return self._do_update(
+            tenant_id, shares, snapshots, gigabytes, snapshot_gigabytes,
+            share_networks, force, user_id,
+            share_type=share_type,
+            share_groups=share_groups,
+            share_group_snapshots=share_group_snapshots,
+            share_replicas=share_replicas,
+            replica_gigabytes=replica_gigabytes,
+            per_share_gigabytes=per_share_gigabytes,
+            resource_path=RESOURCE_PATH
+        )
+
+    @api_versions.wraps("2.90")  # noqa
+    def update(self, tenant_id, user_id=None, share_type=None,  # noqa
+               shares=None, snapshots=None, gigabytes=None,
+               snapshot_gigabytes=None, share_networks=None,
+               share_groups=None, share_group_snapshots=None,
+               share_replicas=None, replica_gigabytes=None, force=None,
+               per_share_gigabytes=None, encryption_keys=None):
+        self._validate_st_and_sn_in_same_request(share_type, share_networks)
+        return self._do_update(
+            tenant_id, shares, snapshots, gigabytes, snapshot_gigabytes,
+            share_networks, force, user_id,
+            share_type=share_type,
+            share_groups=share_groups,
+            share_group_snapshots=share_group_snapshots,
+            share_replicas=share_replicas,
+            replica_gigabytes=replica_gigabytes,
+            per_share_gigabytes=per_share_gigabytes,
+            encryption_keys=encryption_keys,
+            resource_path=RESOURCE_PATH
+        )
+
     @api_versions.wraps("1.0", "2.6")
     def defaults(self, tenant_id):
         return self._get(
