@@ -13,6 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from manilaclient import api_versions
 from manilaclient import base
 
 RESOURCES_PATH = '/share-networks/%(share_network_id)s/subnets'
@@ -20,7 +21,7 @@ RESOURCE_PATH = RESOURCES_PATH + '/%(share_network_subnet_id)s'
 RESOURCE_NAME = 'share_network_subnet'
 
 
-class ShareNetworkSubnet(base.Resource):
+class ShareNetworkSubnet(base.MetadataCapableResource):
     """Network subnet info for Manila share networks."""
     def __repr__(self):
         return "<ShareNetworkSubnet: %s>" % self.id
@@ -33,18 +34,22 @@ class ShareNetworkSubnet(base.Resource):
         self.manager.delete(self)
 
 
-class ShareNetworkSubnetManager(base.ManagerWithFind):
+class ShareNetworkSubnetManager(base.MetadataCapableManager):
     """Manage :class:`ShareNetworkSubnet` resources."""
 
     resource_class = ShareNetworkSubnet
+    resource_path = '/share-networks'
+    subresource_path = '/subnets'
 
-    def create(self, neutron_net_id=None, neutron_subnet_id=None,
-               availability_zone=None, share_network_id=None):
+    def _do_create(self, neutron_net_id=None, neutron_subnet_id=None,
+                   availability_zone=None, share_network_id=None,
+                   metadata=None):
         """Create share network subnet.
 
         :param neutron_net_id: ID of Neutron network
         :param neutron_subnet_id: ID of Neutron subnet
         :param availability_zone: Name of the target availability zone
+        :param metadata: dict - optional metadata to set on share creation
         :rtype: :class:`ShareNetworkSubnet`
         """
         values = {}
@@ -54,6 +59,8 @@ class ShareNetworkSubnetManager(base.ManagerWithFind):
             values['neutron_subnet_id'] = neutron_subnet_id
         if availability_zone:
             values['availability_zone'] = availability_zone
+        if metadata:
+            values['metadata'] = metadata
 
         body = {'share-network-subnet': values}
         url = '/share-networks/%(share_network_id)s/subnets' % {
@@ -62,6 +69,18 @@ class ShareNetworkSubnetManager(base.ManagerWithFind):
 
         return self._create(url, body, RESOURCE_NAME)
 
+    @api_versions.wraps("2.0", "2.77")
+    def create(self, neutron_net_id=None, neutron_subnet_id=None,
+               availability_zone=None, share_network_id=None):
+        return self._do_create(neutron_net_id, neutron_subnet_id,
+                               availability_zone, share_network_id)
+
+    @api_versions.wraps("2.78")
+    def create(self, neutron_net_id=None, neutron_subnet_id=None, # noqa F811
+               availability_zone=None, share_network_id=None, metadata=None):
+        return self._do_create(neutron_net_id, neutron_subnet_id,
+                               availability_zone, share_network_id, metadata)
+
     def get(self, share_network, share_network_subnet):
         """Get a share network subnet.
 
@@ -89,3 +108,23 @@ class ShareNetworkSubnetManager(base.ManagerWithFind):
             'share_network_subnet': share_network_subnet
         }
         self._delete(url)
+
+    @api_versions.wraps('2.78')
+    def get_metadata(self, share_network, share_network_subnet):
+        return super(ShareNetworkSubnetManager, self).get_metadata(
+            share_network, subresource=share_network_subnet)
+
+    @api_versions.wraps('2.78')
+    def set_metadata(self, resource, metadata, subresource=None):
+        return super(ShareNetworkSubnetManager, self).set_metadata(
+            resource, metadata, subresource=subresource)
+
+    @api_versions.wraps('2.78')
+    def delete_metadata(self, resource, keys, subresource=None):
+        return super(ShareNetworkSubnetManager, self).delete_metadata(
+            resource, keys, subresource=subresource)
+
+    @api_versions.wraps('2.78')
+    def update_all_metadata(self, resource, metadata, subresource=None):
+        return super(ShareNetworkSubnetManager, self).update_all_metadata(
+            resource, metadata, subresource=subresource)
